import pickle
import os
import sys
import numpy as np
np.set_printoptions(threshold=sys.maxsize)

# traj_dir = "/home/aryaman/Campus data/2021-09-30-15-47-09/ut-walrus-output.pickle"
# traj_file = open(traj_dir, 'rb')
# traj_data = pickle.load(traj_file)
# print(traj_data.keys())
# print(traj_data['model_info'])
# print(type(traj_data['data']))

def load_map_file(traj_dir):
	""" Load the Trajectory and phoenix map environment from a pickle file
		:param traj_dir : Name of the pickle file containing the representation of the Phoenix environment
	"""
	# Open the pickle file and load it
	traj_file = open(traj_dir, 'rb')
	traj_data = pickle.load(traj_file)
	print(traj_data.keys())
	print(traj_data['model_info'])
	print(type(traj_data['data']))
	# We only care about the data field of the environment
	traj_data = traj_data['data']
	# Check if the map configuration are valid and obtain the map lwidth and height
	n_row = None
	n_col = None
	n_feat = None
	# Perform some printing to check if the map file make some sense
	for elem in traj_data:
		print('Demo ID      : {}'.format(elem['demonstration_id']))
		print('(height, width)  : ({}, {})'.format(elem['map_height'], elem['map_width'] ))
		print('Features : {}'.format(elem['features']))
		print('Features type    : {}'.format(elem['feature_type']))
		print('Traj length  : {} | start = {}, end = {}'.format(len(elem['trajectory']), elem['trajectory'][0],elem['trajectory'][-1] ))
		assert elem['feature_map_numpy'].shape[:-1] == (elem['map_height'], elem['map_width']), 'Feature map does not match map dimension'
		print('------------------------------------------------')
		assert (n_row is None and n_col is None) or (n_row, n_col) == elem['feature_map_numpy'].shape[:-1], 'Dimensions should match accross demonstrations'
		n_row, n_col = elem['feature_map_numpy'].shape[:-1]
		assert n_feat is None or n_feat == len(elem['features']), 'Number of features should match accross demonstrations'
		n_feat = len(elem['features'])
	# Now handle the robot position and state
	m_robot_state_evol = list()
	for elem in traj_data:
		demo_id = elem['demonstration_id']
		robot_trajectory = elem['trajectory']
		m_traj = list()
		for(x,y) in robot_trajectory:
			feat_name = [ feat for (r, feat) in zip(elem['feature_map_numpy'][y,x], elem['features']) if r == 1.0]
			feat_name = feat_name[0] if len(feat_name)>0 else "UNKNOWN_FEATURE"
			m_traj.append((y,x,feat_name)) # State are in row, column definition
		m_robot_state_evol.append((demo_id, m_traj))
			
	return (n_row, n_col, n_feat), traj_data

dir_pickle = os.path.join(sys.path[0], "ut-walrus-output.pickle")
# load_map_file(dir_pickle)
# file = open("/home/aryaman/Campus data/output_numpy_map.txt", "w")
# file.write(str(load_map_file(dir_pickle)[1][0]['feature_map_numpy']))  
# file.close()
# traj_data['data'][0]['feature_map_numpy']
# print(len(load_map_file(dir_pickle)[1][0]['feature_map_numpy'][1]))
# with open('save.npy', 'wb') as f:
np.save('save.npy', np.array(load_map_file(dir_pickle)[1][0]['feature_map_numpy']))